pub struct ColorOptions {
pub num_colors: Option<u32>,
pub loss: LossAlgorithm,
}Expand description
The options for transforming an image to have a different color depth.
Fields
num_colors: Option<u32>The maximum number of colors to admit.
None means no limit
loss: LossAlgorithmThe distance algorithm to use for calculating the loss between colors.
The default is L2.